pub fn vanilla_structure_sets() -> Vec<StructureSetData>Expand description
Returns all vanilla structure sets parsed from the datapack.
pub fn vanilla_structure_sets() -> Vec<StructureSetData>Returns all vanilla structure sets parsed from the datapack.